@@ -21,11 +21,10 @@
 #' the function will perform a subsetting to ensure this condition.
 #' @param weights Matrix with climatological weights which can be obtained using
 #' the \code{CST_RFWeights} function. If \code{weights=1.} (default) no weights are used.
-#' The matrix should have dimensions (lon, lat) in this order.
-#' The names of these dimensions are not checked. 
+#' The names of these dimensions must be at least 'lon' and 'lat'. 
 #' @param nf Refinement factor for downscaling (the output resolution is increased by this factor).
 #' @param slope Prescribed spectral slope. The default is \code{slope=0.}
-#' meaning that the slope is determined automatically over the dimensions specified by \code{time_dim}.
+#' meaning that the slope is determined automatically over the dimensions specified by \code{time_dim}. A 1D array with named dimension can be provided (see details and examples)
 #' @param kmin First wavenumber for spectral slope (default: \code{kmin=1}).
 #' @param nens Number of ensemble members to produce (default: \code{nens=1}).
 #' @param fglob Logical to conserve global precipitation over the domain (default: FALSE).
@@ -51,10 +50,11 @@
 #' 
 #' @return CST_RainFARM() returns a downscaled CSTools object (i.e., of the 
 #' class 's2dv_cube').
-#' If \code{nens>1} an additional dimension named "realization" is added to the 
+#' If \code{nens>1} an additional dimension named "realizatio"n is added to the 
 #' \code{$data} array after the "member" dimension (unless 
 #' \code{drop_realization_dim=TRUE} is specified).
 #' The ordering of the remaining dimensions in the \code{$data} element of the input object is maintained.
+#' @details Wether parameter 'slope' and 'weights' presents seasonality dependency, a dimension name should match between these parameters and the input data in parameter 'data'. See example 2 below where weights and slope vary with 'sdate' dimension.
 #' @import multiApply
 #' @import rainfarmr
 #' @examples
@@ -68,8 +68,8 @@
 #' dim(lat) <- c(lat = length(lat))
 #' data <- list(data = exp, lon = lon, lat = lat)
 #' # Create a test array of weights
-#' ww <- array(1., dim = c(8 * nf, 8 * nf))
-#' res <- CST_RainFARM(data, nf, ww, nens=3)
+#' ww <- array(1., dim = c(lon = 8 * nf, lat = 8 * nf))
+#' res <- CST_RainFARM(data, nf = nf, weights = ww, nens=3)
 #' str(res)
 #' #List of 3
 #' # $ data: num [1, 1:2, 1:3, 1:3, 1:4, 1:64, 1:64] 260 553 281 278 143 ...
@@ -79,20 +79,28 @@
 #' # dataset      member realization       sdate       ftime         lat         lon 
 #' #       1           2           3           3           4          64          64
 #' 
+#' # Example 2:
+#' slo <- array(c(0.1, 0.5, 0.7), c(sdate= 3))
+#' wei <- array(rnorm(8 * 8 * 3), c(lon = 8, lat = 8, sdate = 3))
+#' res <- CST_RainFARM(lonlat_prec,
+#'                     weights = wei, slope = slo, nf = 2)
 #' @export
-CST_RainFARM <- function(data, nf, weights = 1., slope = 0, kmin = 1,
+CST_RainFARM <- function(data, weights = 1., slope = 0, nf, kmin = 1,
                          nens = 1, fglob = FALSE, fsmooth = TRUE,
                          nprocs = 1, time_dim = NULL, verbose = FALSE,
                          drop_realization_dim = FALSE) {
 
   res <- RainFARM(data$data, data$lon, data$lat,
-                  nf, weights, nens, slope, kmin, fglob, fsmooth,
+                  nf = nf, weights = weights, nens, slope, kmin, fglob, fsmooth,
                   nprocs, time_dim, lon_dim = "lon", lat_dim = "lat",
                   drop_realization_dim, verbose)
-
+  att_lon <- attributes(data$lon)[-1]
+  att_lat <- attributes(data$lat)[-1]
   data$data <- res$data
   data$lon <- res$lon
+  attributes(data$lon) <- att_lon
   data$lat <- res$lat
+  attributes(data$lat) <- att_lat 
 
   return(data)
 }
@@ -117,13 +125,12 @@ CST_RainFARM <- function(data, nf, weights = 1., slope = 0, kmin = 1,
 #' the function will perform a subsetting to ensure this condition.
 #' @param lon Vector or array of longitudes.
 #' @param lat Vector or array of latitudes.
-#' @param weights Matrix with climatological weights which can be obtained using
+#' @param weights multi-dimensional array with climatological weights which can be obtained using
 #' the \code{CST_RFWeights} function. If \code{weights=1.} (default) no weights are used.
-#' The matrix should have dimensions (lon, lat) in this order.
-#' The names of these dimensions are not checked. 
-#' @param nf Refinement factor for downscaling (the output resolution is increased by this factor).
+#' The names of these dimensions must be at least 'lon' and 'lat'.
+#' @param nf Refinement factor for downscaling (the output resolution is increased by this factor). 
 #' @param slope Prescribed spectral slope. The default is \code{slope=0.}
-#' meaning that the slope is determined automatically over the dimensions specified by \code{time_dim}.
+#' meaning that the slope is determined automatically over the dimensions specified by \code{time_dim}. A 1D array with named dimension can be provided (see details and examples)
 #' @param kmin First wavenumber for spectral slope (default: \code{kmin=1}).
 #' @param nens Number of ensemble members to produce (default: \code{nens=1}).
 #' @param fglob Logical to conseve global precipitation over the domain (default: FALSE)
@@ -153,7 +160,10 @@ CST_RainFARM <- function(data, nf, weights = 1., slope = 0, kmin = 1,
 #' If \code{nens>1} an additional dimension named "realization" is added to the output array
 #' after the "member" dimension (if it exists and unless \code{drop_realization_dim=TRUE} is specified).
 #' The ordering of the remaining dimensions in the \code{exp} element of the input object is maintained.
+#' @details Wether parameter 'slope' and 'weights' presents seasonality dependency, a dimension name should match between these parameters and the input data in parameter 'data'. See example 2 below where weights and slope vary with 'sdate' dimension.
 #' @import multiApply
+#' @importFrom s2dverification Subset
+#' @importFrom abind abind
 #' @export
 #' @examples
 #' # Example for the 'reduced' RainFARM function 
@@ -166,7 +176,7 @@ CST_RainFARM <- function(data, nf, weights = 1., slope = 0, kmin = 1,
 #' lon_mat <- seq(10, 13.5, 0.5) # could also be a 2d matrix
 #' lat_mat <- seq(40, 43.5, 0.5)
 #' # Create a test array of weights
-#' ww <- array(1., dim = c(8 * nf, 8 * nf))
+#' ww <- array(1., dim = c(lon = 8 * nf, lat = 8 * nf))
 #' # or create proper weights using an external fine-scale climatology file
 #' #     Specify a weightsfn filename if you wish to save the weights
 #' \dontrun{
@@ -185,7 +195,11 @@ CST_RainFARM <- function(data, nf, weights = 1., slope = 0, kmin = 1,
 #' dim(res$data)
 #' #  lon         lat       ftime realization 
 #' #   64          64          20           2 
-#'
+#' # Example 2:
+#' slo <- array(c(0.1, 0.5, 0.7), c(sdate= 3))
+#' wei <- array(rnorm(8*8*3), c(lon = 8, lat = 8, sdate = 3))
+#' res <- RainFARM(lonlat_prec$data, lon = lonlat_prec$lon,
+#'                 lat = lonlat_prec$lat, weights = wei, slope = slo, nf = 2)
 RainFARM <- function(data, lon, lat, nf, weights = 1., nens = 1,
                      slope = 0, kmin = 1, fglob = FALSE, fsmooth = TRUE,
                      nprocs = 1, time_dim = NULL, lon_dim = "lon", lat_dim = "lat",
@@ -211,13 +225,28 @@ RainFARM <- function(data, lon, lat, nf, weights = 1., nens = 1,
     warning(paste0("lon: [", lon[1], ", ", lon[length(lon)], "] ",
                  " lat: [", lat[1], ", ", lat[length(lat)], "]"))
   }
-  if (!(length(dim(weights)) == 0) &
-      !(all(dim(weights) == c(dim(data)[lon_dim] * nf,
-                              dim(data)[lat_dim] * nf)))) {
+  if (length(dim(weights)) > 0) {
+    if (length(names(dim(weights))) == 0) {
+      stop("Parameter 'weights' must have dimension names when it is not a scalar.")
+    } else {
+      if (length(which(names(dim(weights)) == 'lon')) > 0 &
+          length(which(names(dim(weights)) == 'lat')) > 0) { 
+        lonposw <- which(names(dim(weights)) == 'lon')
+        latposw <- which(names(dim(weights)) == 'lat')
+      } else {
+        stop("Parameter 'weights' must have dimension names 'lon' and 'lat' when",
+             " it is not a scalar.")
+      }
+    }
+  }
+  if (!(length(dim(weights)) == 0)) { 
+    if (!(dim(weights)[lonposw] == dim(data)[lon_dim] * nf) &
+        !(dim(weights)[latposw] == dim(data)[lat_dim] * nf)) {
     stop(paste("The dimensions of the weights matrix (", dim(weights)[1],
                "x", dim(weights)[2] ,
                ") are not consistent with the size of the data (",
                dim(data)[lon_dim], ") and the refinement factor (", nf, ")"))
+    }
   }
   # Check/detect time_dim
   if (is.null(time_dim)) {
@@ -238,11 +267,11 @@ RainFARM <- function(data, lon, lat, nf, weights = 1., nens = 1,
     warning(paste("Selected time dim:", time_dim))
   }
   # Check if slope is an array
-  if (length(slope) > 1) {
-    warning("Parameter 'slope' has length > 1 and only the first ",
-            "element will be used.")
-    slope <- as.numeric(slope[1])
-  }
+  #if (length(slope) > 1) {
+  #  warning("Parameter 'slope' has length > 1 and only the first ",
+  #          "element will be used.")
+  #  slope <- as.numeric(slope[1])
+  #}
 
   # Perform common calls
   r <- lon_lat_fine(lon, lat, nf)
@@ -259,14 +288,33 @@ RainFARM <- function(data, lon, lat, nf, weights = 1., nens = 1,
   dim(data) <- c(cdim[ind], rainfarm_samples = prod(cdim[-ind]))
 
   # Repeatedly apply .RainFARM
-  result <- Apply(data, c(lon_dim, lat_dim, "rainfarm_samples"), .RainFARM,
-                  weights, nf, nens, slope, kmin,
-                  fglob, fsmooth, ncores = nprocs, verbose,
-                  split_factor = "greatest")$output1
+  if (length(weights) == 1 & length(slope) == 1) {
+    result <- Apply(data, c(lon_dim, lat_dim, "rainfarm_samples"), .RainFARM,
+                    weights, slope, nf, nens, kmin,
+                    fglob, fsmooth, ncores = nprocs, verbose,
+                    split_factor = "greatest")$output1
+  } else if (length(slope) == 1 & length(weights) > 1 ) {
+     result <- Apply(list(data, weights),
+                     list(c(lon_dim, lat_dim, "rainfarm_samples"),
+                          c(lonposw, latposw)), 
+                    .RainFARM, slope = slope,
+                    nf = nf, nens = nens, kmin = kmin,
+                    fglob = fglob, fsmooth = fsmooth, ncores = nprocs,
+                    verbose = verbose,
+                    split_factor = "greatest")$output1
+  } else {
+     result <- Apply(list(data, weights, slope),  
+                     list(c(lon_dim, lat_dim, "rainfarm_samples"), 
+                          c(lonposw, latposw), NULL), 
+                     fun = .RainFARM,
+                     nf = nf, nens = nens, kmin = kmin,
+                     fglob = fglob, fsmooth = fsmooth, ncores = nprocs,
+                     verbose = verbose,
+                     split_factor = "greatest")$output1
+  }
   # result has dims: lon, lat, rainfarm_samples, realization, other dims
   # Expand back rainfarm_samples to compacted dims
   dim(result) <- c(dim(result)[1:2], cdim[-ind], dim(result)[-(1:3)])
-
   # Reorder as it was in original data
   # + realization dim after member if it exists
   ienspos <- which(names(cdim0) == "member")
@@ -282,7 +330,6 @@ RainFARM <- function(data, lon, lat, nf, weights = 1., nens = 1,
   if (drop_realization_dim) {
     cdim <- dim(result)
     if (nens == 1) {
-      # just drop it if only one member
       dim(result) <- cdim[-which(names(cdim) == "realization")[1]]
     } else if ("member" %in% names(cdim)) {
       # compact member and realization dimension if member dim exists,
@@ -295,7 +342,6 @@ RainFARM <- function(data, lon, lat, nf, weights = 1., nens = 1,
       names(dim(result))[ind] <- "member"
     }
   }
-
   return(list(data = result, lon = lon_f, lat = lat_f))
 }
 
@@ -303,8 +349,8 @@ RainFARM <- function(data, lon, lat, nf, weights = 1., nens = 1,
 #' @param pr Precipitation array to downscale with dimensions (lon, lat, time).
 #' @param weights Matrix with climatological weights which can be obtained using
 #' the \code{CST_RFWeights} function (default: \code{weights=1.} i.e. no weights).
-#' @param nf Refinement factor for downscaling (the output resolution is increased by this factor).
 #' @param slope Prescribed spectral slope (default: \code{slope=0.}
+#' @param nf Refinement factor for downscaling (the output resolution is increased by this factor).
 #' meaning that the slope is determined automatically over the dimensions specified by \code{time_dim}.
 #' @param kmin First wavenumber for spectral slope (default: \code{kmin=1}).
 #' @param nens Number of ensemble members to produce (default: \code{nens=1}).
@@ -313,24 +359,44 @@ RainFARM <- function(data, lon, lat, nf, weights = 1., nens = 1,
 #' @param verbose Logical for verbose output (default: FALSE).
 #' @return .RainFARM returns a downscaled array with dimensions (lon, lat, time, realization)
 #' @noRd
-.RainFARM <- function(pr, weights, nf, nens, slope, kmin,
+.RainFARM <- function(pr, weights, slope, nf, nens, kmin,
                       fglob, fsmooth, verbose) {
-
+  posna <- NULL
+  if (any(is.na(pr))) {
+    posna <- unlist(lapply(1:dim(pr)['rainfarm_samples'],
+                         function(x){!is.na(pr[1, 1, x])}))
+    pr <- Subset(pr, 'rainfarm_samples', posna)
+  }
   if (slope == 0) {
     fxp <- fft2d(pr)
     sx <- fitslope(fxp, kmin = kmin)
   } else {
     sx <- slope
   }
-
   result_dims <- c(dim(pr)[1] * nf, dim(pr)[2] * nf, dim(pr)[3],
                    realization = nens)
   r <- array(dim = result_dims)
-
   for (i in 1:nens) {
     r[, , , i] <- rainfarm(pr, sx, nf, weights, fglob = fglob,
                            fsmooth = fsmooth, verbose = verbose)
   }
+  # restoring NA values in their position:
+  if (!is.null(posna)) {
+    pos <- which(posna == FALSE)
+    dimdata <- dim(r)
+    xdim <- which(names(dimdata) == 'rainfarm_samples')
+    dimdata[xdim] <- dimdata[xdim] + length(pos)
+    new <- array(NA, dimdata)
+    posT <- which(posna == TRUE)
+    i = 1
+    invisible(lapply(posT, function(x) {
+                             new[,,x,] <<- r[,,i,]
+                             i <<- i + 1
+                    }))
+    #names(dim(r)) <- names(result_dims)
+    warning("Missing values found in the samples.")
+    r <- new
+  }
   return(r)
 }
 
